aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--discord/guild.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/discord/guild.py b/discord/guild.py
index b781a360..1f78de42 100644
--- a/discord/guild.py
+++ b/discord/guild.py
@@ -470,7 +470,7 @@ class Guild(Hashable):
@property
def rules_channel(self):
"""Optional[:class:`TextChannel`]: Return's the guild's channel used for the rules.
Must be a discoverable guild.
If no channel is set, then this returns ``None``.
@@ -482,8 +482,8 @@ class Guild(Hashable):
@property
def public_updates_channel(self):
"""Optional[:class:`TextChannel`]: Return's the guild's channel where admins and
- moderators of the guilds receive notices from Discord. This is only available to
- guilds that contain ``PUBLIC`` in :attr:`Guild.features`.
+ moderators of the guilds receive notices from Discord. The guild must be a
+ Community guild.
If no channel is set, then this returns ``None``.
@@ -470,7 +470,7 @@ class Guild(Hashable):
def rules_channel(self):
"""Optional[:class:`TextChannel`]: Return's the guild's channel used for the rules.
- Must be a discoverable guild.
+ The guild must be a Community guild.
If no channel is set, then this returns ``None``.